summaryrefslogtreecommitdiff
path: root/src/mm-iface-modem-3gpp.h
diff options
context:
space:
mode:
authorAleksander Morgado <aleksander@lanedo.com>2012-08-09 10:31:01 +0200
committerAleksander Morgado <aleksander@lanedo.com>2012-08-29 17:26:45 +0200
commitfe4d94788badc3b41f60919b0bb635a54f5cda08 (patch)
tree77e6e73d6937a9eba760f4e5e04ea9a198a93b15 /src/mm-iface-modem-3gpp.h
parent483f59c01def1df37a6fe85e19aebf1c1a1532f3 (diff)
downloadModemManager-fe4d94788badc3b41f60919b0bb635a54f5cda08.tar.gz
iface-modem-3gpp: provide separate methods to update access tech and location
Diffstat (limited to 'src/mm-iface-modem-3gpp.h')
-rw-r--r--src/mm-iface-modem-3gpp.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/mm-iface-modem-3gpp.h b/src/mm-iface-modem-3gpp.h
index dc96ff1bb..2bc25613e 100644
--- a/src/mm-iface-modem-3gpp.h
+++ b/src/mm-iface-modem-3gpp.h
@@ -211,19 +211,19 @@ gboolean mm_iface_modem_3gpp_disable_finish (MMIfaceModem3gpp *self,
/* Shutdown Modem 3GPP interface */
void mm_iface_modem_3gpp_shutdown (MMIfaceModem3gpp *self);
/* Objects implementing this interface can report new registration states.
* This may happen when handling unsolicited registration messages, or when
* the interface asks to run registration state checks. */
void mm_iface_modem_3gpp_update_cs_registration_state (MMIfaceModem3gpp *self,
- MMModem3gppRegistrationState state,
- MMModemAccessTechnology access_tech,
- gulong location_area_code,
- gulong cell_id);
+ MMModem3gppRegistrationState state);
void mm_iface_modem_3gpp_update_ps_registration_state (MMIfaceModem3gpp *self,
- MMModem3gppRegistrationState state,
- MMModemAccessTechnology access_tech,
- gulong location_area_code,
- gulong cell_id);
+ MMModem3gppRegistrationState state);
+void mm_iface_modem_3gpp_update_access_technologies (MMIfaceModem3gpp *self,
+ MMModemAccessTechnology access_tech);
+void mm_iface_modem_3gpp_update_location (MMIfaceModem3gpp *self,
+ gulong location_area_code,
+ gulong cell_id);
/* Run all registration checks */
void mm_iface_modem_3gpp_run_registration_checks (MMIfaceModem3gpp *self,
@@ -211,19 +211,19 @@ gboolean mm_iface_modem_3gpp_disable_finish (MMIfaceModem3gpp *self,
/* Shutdown Modem 3GPP interface */
void mm_iface_modem_3gpp_shutdown (MMIfaceModem3gpp *self);
-/* Objects implementing this interface can report new registration states.
+/* Objects implementing this interface can report new registration states,
+ * access technologies and location.
* This may happen when handling unsolicited registration messages, or when
* the interface asks to run registration state checks. */